@@ -12,7 +12,7 @@ from pysnowball.report import (report, earningforecast)
 from pysnowball.capital import(
     margin, blocktrans, capital_assort, capital_flow, capital_history)
 
-from pysnowball.realtime import(quotec, pankou)
+from pysnowball.realtime import(quotec, pankou, quote_detail)
 
 from pysnowball.f10 import(skholderchg, skholder, main_indicator,
                            industry, holders, bonus, org_holding_change,
@@ -24,4 +24,8 @@ from pysnowball.user import(watch_list, watch_stock)
 
 from pysnowball.cube import(nav_daily, rebalancing_history)
 
-from pysnowball.quote import detail as quote_detail
+from pysnowball.bond import(convertible_bond)
+
+from pysnowball.index import(index_basic_info, index_details_data, index_weight_top10,
+                             index_perf_7, index_perf_30, index_perf_90)
+
